@@ -225,6 +225,15 @@
         cb(self, virDomain(self, _obj=dom), iteration, opaque)
         return 0
 
+    def _dispatchDomainEventJobCompletedCallback(self, dom, params, cbData):
+        """Dispatches event to python user domain job completed callbacks
+        """
+        cb = cbData["cb"]
+        opaque = cbData["opaque"]
+
+        cb(self, virDomain(self, _obj=dom), params, opaque)
+        return 0
+
     def domainEventDeregisterAny(self, callbackID):
         """Removes a Domain Event Callback. De-registering for a
            domain callback will disable delivery of this event type """
